---
name: Bug report
about: Create a bug report of something that is currently not working
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Provide a minimal code example that reproduces the error

**Expected behavior**
A clear and concise description of what you expected to happen. If an exception is raised, please provide the exception traceback.

**Desktop (please complete the following information):**
 - OS: [e.g. Windows, MacOS]
 - Python version: [e.g. 3.8.1]
 - Chaospy version [e.g. 4.0.1]

**Additional context**
Add any other context about the problem here.
